pub struct IpAddresses {
    pub client: Client,
}

Fields

client: Client

Implementations

Retrieve all IP addresses.

This function performs a GET to the /ips endpoint.

This endpoint allows you to retrieve a list of all assigned and unassigned IPs.

Response includes warm up status, pools, assigned subusers, and reverse DNS info. The start_date field corresponds to when warmup started for that IP.

A single IP address or a range of IP addresses may be dedicated to an account in order to send email for multiple domains. The reputation of this IP is based on the aggregate performance of all the senders who use it.

Parameters:

  • ip: &str – The license key provided with your New Relic account.
  • exclude_whitelabels: bool – Indicates if your subuser statistics will be sent to your New Relic Dashboard.
  • limit: i64 – The number of IPs you want returned at the same time.
  • offset: i64 – The offset for the number of IPs that you are requesting.
  • subuser: &str – The license key provided with your New Relic account.
  • sort_by_direction: crate::types::SortByDirection – The direction to sort the results.

Retrieve all IP addresses.

This function performs a GET to the /ips endpoint.

As opposed to get_ips, this function returns all the pages of the request at once.

This endpoint allows you to retrieve a list of all assigned and unassigned IPs.

Response includes warm up status, pools, assigned subusers, and reverse DNS info. The start_date field corresponds to when warmup started for that IP.

A single IP address or a range of IP addresses may be dedicated to an account in order to send email for multiple domains. The reputation of this IP is based on the aggregate performance of all the senders who use it.

Add IPs.

This function performs a POST to the /ips endpoint.

This endpoint is for adding a(n) IP Address(es) to your account.

Get remaining IPs count.

This function performs a GET to the /ips/remaining endpoint.

This endpoint gets amount of IP Addresses that can still be created during a given period and the price of those IPs.

Retrieve all assigned IPs.

This function performs a GET to the /ips/assigned endpoint.

This endpoint allows you to retrieve only assigned IP addresses.

A single IP address or a range of IP addresses may be dedicated to an account in order to send email for multiple domains. The reputation of this IP is based on the aggregate performance of all the senders who use it.

Retrieve all assigned IPs.

This function performs a GET to the /ips/assigned endpoint.

As opposed to get_ips_assigned, this function returns all the pages of the request at once.

This endpoint allows you to retrieve only assigned IP addresses.

A single IP address or a range of IP addresses may be dedicated to an account in order to send email for multiple domains. The reputation of this IP is based on the aggregate performance of all the senders who use it.

Retrieve all IP pools an IP address belongs to.

This function performs a GET to the /ips/{ip_address} endpoint.

This endpoint allows you to see which IP pools a particular IP address has been added to.

The same IP address can be added to multiple IP pools.

A single IP address or a range of IP addresses may be dedicated to an account in order to send email for multiple domains. The reputation of this IP is based on the aggregate performance of all the senders who use it.