pub struct IpWarmup {
    pub client: Client,
}

Fields

client: Client

Implementations

Retrieve all IPs currently in warmup.

This function performs a GET to the /ips/warmup endpoint.

This endpoint allows you to retrieve all of your IP addresses that are currently warming up.

Retrieve all IPs currently in warmup.

This function performs a GET to the /ips/warmup endpoint.

As opposed to get_ips_warmup, this function returns all the pages of the request at once.

This endpoint allows you to retrieve all of your IP addresses that are currently warming up.

Start warming up an IP address.

This function performs a POST to the /ips/warmup endpoint.

This endpoint allows you to put an IP address into warmup mode.

Retrieve the warmup status for a specific IP address.

This function performs a GET to the /ips/warmup/{ip_address} endpoint.

This endpoint allows you to retrieve the warmup status for a specific IP address.

You can retrieve all of your warming IPs using the “Retrieve all IPs currently in warmup” endpoint.

Retrieve the warmup status for a specific IP address.

This function performs a GET to the /ips/warmup/{ip_address} endpoint.

As opposed to get_ips_warmup_ip_address, this function returns all the pages of the request at once.

This endpoint allows you to retrieve the warmup status for a specific IP address.

You can retrieve all of your warming IPs using the “Retrieve all IPs currently in warmup” endpoint.

Stop warming up an IP address.

This function performs a DELETE to the /ips/warmup/{ip_address} endpoint.

This endpoint allows you to remove an IP address from warmup mode.

Your request will return a 204 status code if the specified IP was successfully removed from warmup mode. To retrieve details of the IP’s warmup status before removing it from warmup mode, call the “Retrieve the warmpup status for a specific IP address” endpoint.