pub struct SingleSignOnTeammates {
pub client: Client,
}Fields
client: ClientImplementations
Sourceimpl SingleSignOnTeammates
impl SingleSignOnTeammates
Sourcepub async fn post_sso_teammate(
&self,
body: &SsoTeammateRequestAllOf,
) -> Result<Response<SsoTeammateResponseAllOf>, ClientError>
pub async fn post_sso_teammate( &self, body: &SsoTeammateRequestAllOf, ) -> Result<Response<SsoTeammateResponseAllOf>, ClientError>
Create SSO Teammate.
This function performs a POST to the /sso/teammates endpoint.
This endpoint allows you to create an SSO Teammate.
The email provided for this user will also function as the Teammate’s username.
Sourcepub async fn patch_sso_teammates_username(
&self,
username: &str,
body: &PatchSsoTeammatesUsernameRequest,
) -> Result<Response<SsoTeammatesPatchResponseAllOf>, ClientError>
pub async fn patch_sso_teammates_username( &self, username: &str, body: &PatchSsoTeammatesUsernameRequest, ) -> Result<Response<SsoTeammatesPatchResponseAllOf>, ClientError>
Edit an SSO Teammate.
This function performs a PATCH to the /sso/teammates/{username} endpoint.
This endpoint allows you to modify an existing SSO Teammate.
To turn a teammate into an admin, the request body should contain the is_admin field set to true. Otherwise, set is_admin to false and pass in all the scopes that a teammate should have.
Only the parent user and Teammates with admin permissions can update another Teammate’s permissions. Admin users can only update permissions.